Optional plugins
================

As well as the standard FEZ verbs, which allow you to do most of the "manual"
layout operations which should be familiar to users of AFDKO, FEZ includes a
number of additional plugins which are not loaded by default, but which provide
higher-level functionality.

As well as being useful *per se* for font engineers, inspecting the source code
to these plugins is also a good way to learn how to write your own plugins and
add verbs to the language.

.. automodule:: fez.Arabic
.. automodule:: fez.BariYe
.. automodule:: fez.FontEngineering
.. automodule:: fez.IMatra
.. automodule:: fez.KernToDistance
.. automodule:: fez.LigatureFinder
.. automodule:: fez.MedialRa
.. automodule:: fez.Swap
